<?php
session_start();
include_once (__DIR__.'/../config.php');
$pdo = require_once (SERVERDIR .'/database.php');
require_once (LIBSDIR .'/variables.php');
require_once (SERVERDIR .'/auth.php');

const MESSAGES = [
    'NO_ADMIN' => 'You need admin permission to access this action.',
    'UPDATE_PRIVACY_SUCCESS' => 'Privacy Updated Successfully.',
    'UPDATE_PRIVACY_FAILED' => 'Privacy Update faied.'
];

if(isGetRequest()) {
   // print "Request from get";
    if(isset($_GET['query'])) {
        switch($_GET['query']) {
          case 'fetchPrivacyCondition':
            parsePrivacyPolicyToJson();
            break;
          case 'fetchDCMACondition':
            parseDCMAToJson();
            break;
        }
    }
}

if(isPostRequest() && isUserLogedIn()) {
    if(isset($_REQUEST['query'])) {
        switch($_REQUEST['query']) {

            case 'updatePrivacyCondition':
                if(!isCurrentLogedInAsAdmin()) {
                    print json_encode(array("success" => false, "msg" => MESSAGES['NO_ADMIN']), JSON_PRETTY_PRINT);
                    return;
                } 
                if(isset($_REQUEST['app_privacy_policy'])) {
                    $conditionText = $_REQUEST['app_privacy_policy']; // string_strip(['request' => 'app_privacy_policy']);
                    updatePrivacyPolicy();
                }
                break;
            case 'updateDCMACondition':
                if(!isCurrentLogedInAsAdmin()) {
                    print json_encode(array("success" => false, "msg" => MESSAGES['NO_ADMIN']), JSON_PRETTY_PRINT);
                    return;
                } 
                if(isset($_REQUEST['app_dcma_condition'])) {
                    $conditionText = $_REQUEST['app_dcma_condition']; // string_strip(['request' => 'app_privacy_policy']);
                    updateDCMACondition();
                }
                break;
        }
    }
}

function getPrivacyContent() {
    return fetchCondition('tb_privacy') ? fetchCondition('tb_privacy')['text'] : 'No Found';
}

function getDCMAConditionContent() {
    return fetchCondition('tb_dcma') ? fetchCondition('tb_dcma')['text'] : 'No Found';
}

function fetchCondition($table) {
    global $pdo;
    $sql = "SELECT title, text FROM `".$table."`"; 
    $stmt = $pdo->prepare($sql);
    $stmt->execute();
    $row = $stmt->fetch(PDO::FETCH_ASSOC);
    $stmt->closeCursor();
    return $row;
}

function parsePrivacyPolicyToJson() {
    print json_encode(fetchCondition('tb_privacy'), JSON_PRETTY_PRINT);
}

function parseDCMAToJson() {
    print json_encode(fetchCondition('tb_dcma'), JSON_PRETTY_PRINT);
}

function updatePrivacyPolicy() {
    updateCondition('tb_privacy');
}

function updateDCMACondition() {
    updateCondition('tb_dcma');
}

function updateCondition($table) {
    global $pdo, $conditionText, $isAdmin, $msg;
    if(isCurrentLogedInAsAdmin()) {
        if(fetchCondition($table) > 0) {
            if(fetchCondition($table)['text'] != $conditionText) {
                $sql = "UPDATE `".$table."` SET text = :text, created_at = now() WHERE 1";
                $stmt = $pdo->prepare($sql);
                $stmt->bindValue(':text', $conditionText, PDO::PARAM_STR);
                $updateSet = $stmt->execute() ? true : false;
                if($updateSet) {
                    $msg = MESSAGES['UPDATE_PRIVACY_SUCCESS'];
                } else {
                    $updateSet = false;
                    $msg = MESSAGES['UPDATE_PRIVACY_FAILED'];
                }
            } else {
                $updateSet = false;
                $msg = MESSAGES['UPDATE_PRIVACY_FAILED']. ' the condition text already exists';
            }
        } else {
            $sql = "INSERT INTO `".$table."` (text, created_at) VALUES(:text, now()) ";
            $stmt = $pdo->prepare($sql);
            $stmt->bindValue(':text', $conditionText, PDO::PARAM_STR);
            $updateSet = $stmt->execute() ? true : false;
            $msg = MESSAGES['UPDATE_PRIVACY_SUCCESS'];
        }
        $isAdmin = true;
    } else {
        $isAdmin = false;
        $updateSet = false;
        $msg = MESSAGES['NO_ADMIN'];
    }
    print json_encode(array('admin' => $isAdmin, 'success' => $updateSet, 'msg' => $msg), JSON_PRETTY_PRINT);
}

?>