<?php
session_start();
require_once ('../config.php');
$pdo = require_once (SERVERDIR .'/database.php');
require_once (SERVERDIR .'/auth.php');
require_once (LIBSDIR .'/variables.php');

const MESSAGES = [
    'NO_ADMIN' => 'You need admin permission to access this action.',
    'UPDATE_FCM_SUCCESS' => 'FCM Updated Successfully.',
    'UPDATE_FCM_FAILED' => 'FCM Update faied.'
];

if(isPostRequest() && isUserLogedIn()) {
    if(isset($_REQUEST['query'])) {
        switch($_REQUEST['query']) {
            case 'fetchFCMKey':
                parseFCMPushToJson();
                break;
            case 'updateFCMKey':
                if(!isCurrentLogedInAsAdmin()) {
                    print json_encode(array("success" => false, "msg" => MESSAGES['NO_ADMIN']), JSON_PRETTY_PRINT);
                    return;
                } 
                if(isset($_REQUEST['fcm_server_key'])) {
                    $fcmKey = string_strip(['request' => 'fcm_server_key']);
                    updateFcmServerKey();
                }
                break;
        }
    }
}

function getFcmPush() {
    global $pdo;
    $sql = "SELECT * FROM `tb_fcm`"; 
    $stmt = $pdo->prepare($sql);
    $stmt->execute();
    $row = $stmt->fetch(PDO::FETCH_ASSOC);
    $stmt->closeCursor();
    return $row;
}

function parseFCMPushToJson() {
    print json_encode(getFcmPush(), JSON_PRETTY_PRINT);
}

function updateFcmServerKey() {
    global $pdo, $fcmKey, $isAdmin, $msg;
    if(isCurrentLogedInAsAdmin()) {
        if(getFcmPush() > 0) {
            if(getFcmPush()['server_key'] != $fcmKey) {
                $sql = "UPDATE `tb_fcm` SET server_key = :key, created_at = now() WHERE 1";
                $stmt = $pdo->prepare($sql);
                $stmt->bindValue(':key', $fcmKey, PDO::PARAM_STR);
                $updateSet = $stmt->execute() ? true : false;
                if($updateSet) {
                    $msg = MESSAGES['UPDATE_FCM_SUCCESS'];
                } else {
                    $updateSet = false;
                    $msg = MESSAGES['UPDATE_FCM_FAILED'];
                }
            } else {
                $updateSet = false;
                $msg = MESSAGES['UPDATE_FCM_FAILED']. ' the key already exists';
            }
        } else {
            $sql = "INSERT INTO `tb_fcm` (server_key, created_at) VALUES(:key, now()) ";
            $stmt = $pdo->prepare($sql);
            $stmt->bindValue(':key', $fcmKey, PDO::PARAM_STR);
            $updateSet = $stmt->execute() ? true : false;
            $msg = MESSAGES['UPDATE_FCM_SUCCESS'];
        }
        $isAdmin = true;
    } else {
        $isAdmin = false;
        $updateSet = false;
        $msg = MESSAGES['NO_ADMIN'];
    }
    print json_encode(array('admin' => $isAdmin, 'success' => $updateSet, 'msg' => $msg), JSON_PRETTY_PRINT);
}

?>