<?php
session_start();
include_once ('../config.php');
$pdo = require_once (SERVERDIR .'/database.php');
require_once (LIBSDIR .'/variables.php');
require_once (SERVERDIR .'/auth.php');

const MESSAGES = [
    'NO_ADMIN' => 'You need admin permission to access this action.',
    'UPDATE_MONETIZATION_SUCCESS' => 'Monetization Updated Successfully.',
    'UPDATE_MONETIZATION_FAILED' => 'Monetization Update faied.'
];

if(isPostRequest() && isUserLogedIn()) {
    if(isset($_REQUEST['query'])) {
        switch($_REQUEST['query']) {
            case 'fetchMonetization':
                parseMonetizationToJson();
                break;
            case 'updateMonetization':
                if(!isCurrentLogedInAsAdmin()) {
                    print json_encode(array("success" => false, "msg" => MESSAGES['NO_ADMIN']), JSON_PRETTY_PRINT);
                    return;
                } 
                if(isset($_REQUEST['ad_network'])) {
                    $ad_enabled_status = string_strip(['request' => 'ad_enabled_status']);
                    $ad_network = string_strip(['request' => 'ad_network']);
                    $admob_banner_unit_id = string_strip(['request' => 'admob_banner_unit_id']);
                    $admob_native_unit_id = string_strip(['request' => 'admob_native_unit_id']);
                    $admob_interstitial_unit_id = string_strip(['request' => 'admob_interstitial_unit_id']); 
                    $admob_rewarded_unit_id = string_strip(['request' => 'admob_rewarded_unit_id']);
                    $admob_app_open_unit_id = string_strip(['request' => 'admob_app_open_unit_id']); 

                    $unity_game_id = string_strip(['request' => 'unity_game_id']);  
                    $unity_banner_unit_id = string_strip(['request' => 'unity_banner_unit_id']);  
                    $unity_interstitial_unit_id = string_strip(['request' => 'unity_interstitial_unit_id']);  
                    $unity_rewarded_unit_id = string_strip(['request' => 'unity_rewarded_unit_id']);

                    $interstitial_ad_interval = string_strip(['request' => 'interstitial_ad_interval']);
                    $scrolling_ad_interval = string_strip(['request' => 'scrolling_ad_interval']);
                    updateMonetization();
                }
                break;
        }
    }
} else {
    print json_encode(array('array' => "You have not logged in"));
}

function getMonetization() {
    global $pdo;
    $sql = "SELECT * FROM `tb_monetization`"; 
    $stmt = $pdo->prepare($sql);
    $stmt->execute();
    $row = $stmt->fetch(PDO::FETCH_ASSOC);
    $stmt->closeCursor();
    return $row;
}

function parseMonetizationToJson() {
    print json_encode(getMonetization(), JSON_PRETTY_PRINT);
}

function updateMonetization() {
    global $pdo, 
    $ad_enabled_status, 
    $ad_network, 
    $admob_banner_unit_id,  
    $admob_native_unit_id,  
    $admob_interstitial_unit_id,  
    $admob_rewarded_unit_id,  
    $admob_app_open_unit_id,  
    $unity_game_id,  
    $unity_banner_unit_id,  
    $unity_interstitial_unit_id,  
    $unity_rewarded_unit_id,  
    $interstitial_ad_interval,
    $scrolling_ad_interval,
    $isAdmin, 
    $msg;

    if(isCurrentLogedInAsAdmin()) {
        
        if(getMonetization() > 0) {
            $sql = "UPDATE `tb_monetization` SET 
             ad_enabled_status = :ad_enabled_status, 
             ad_network = :ad_network, 
             admob_banner_unit_id = :admob_banner_unit_id,
             admob_native_unit_id = :admob_native_unit_id,
             admob_interstitial_unit_id = :admob_interstitial_unit_id,
             admob_rewarded_unit_id = :admob_rewarded_unit_id,
             admob_app_open_unit_id = :admob_app_open_unit_id,

             unity_game_id = :unity_game_id,
             unity_banner_unit_id = :unity_banner_unit_id,
             unity_interstitial_unit_id = :unity_interstitial_unit_id,
             unity_rewarded_unit_id = :unity_rewarded_unit_id,
             interstitial_ad_interval = :interstitial_ad_interval,
             scrolling_ad_interval = :scrolling_ad_interval,

             created_at = now() WHERE 1";

                $stmt = $pdo->prepare($sql);
                $status = $ad_enabled_status == "on" ? 1 : 0;
                $stmt->bindValue(':ad_enabled_status', $status, PDO::PARAM_INT);
                $stmt->bindValue(':ad_network', $ad_network, PDO::PARAM_STR);
                $stmt->bindValue(':admob_banner_unit_id', $admob_banner_unit_id, PDO::PARAM_STR);
                $stmt->bindValue(':admob_native_unit_id', $admob_native_unit_id, PDO::PARAM_STR);
                $stmt->bindValue(':admob_interstitial_unit_id', $admob_interstitial_unit_id, PDO::PARAM_STR);
                $stmt->bindValue(':admob_rewarded_unit_id', $admob_rewarded_unit_id, PDO::PARAM_STR);
                $stmt->bindValue(':admob_app_open_unit_id', $admob_app_open_unit_id, PDO::PARAM_STR);

                $stmt->bindValue(':unity_game_id', $unity_game_id, PDO::PARAM_STR);
                $stmt->bindValue(':unity_banner_unit_id', $unity_banner_unit_id, PDO::PARAM_STR);
                $stmt->bindValue(':unity_interstitial_unit_id', $unity_interstitial_unit_id, PDO::PARAM_STR);
                $stmt->bindValue(':unity_rewarded_unit_id', $unity_rewarded_unit_id, PDO::PARAM_STR);

                $stmt->bindValue(':interstitial_ad_interval', $interstitial_ad_interval, PDO::PARAM_INT);
                $stmt->bindValue(':scrolling_ad_interval', $scrolling_ad_interval, PDO::PARAM_INT);
                
            
                $updateSet = $stmt->execute() ? true : false;
                if($updateSet) {
                    $msg = MESSAGES['UPDATE_MONETIZATION_SUCCESS'];
                } else {
                    $updateSet = false;
                    $msg = MESSAGES['UPDATE_MONETIZATION_FAILED'];
                }
        } else {
            $sql = "INSERT INTO `tb_monetization` 
                (
                    ad_enabled_status, 
                    ad_network, 
                    admob_banner_unit_id,
                    admob_native_unit_id,
                    admob_interstitial_unit_id,
                    admob_rewarded_unit_id,
                    admob_app_open_unit_id,
                    unity_game_id,
                    unity_banner_unit_id,
                    unity_interstitial_unit_id,
                    unity_rewarded_unit_id,
                    interstitial_ad_interval,
                    scrolling_ad_interval,
                    created_at
                )
             VALUES(
                :ad_enabled_status,
                :ad_network, 
                :admob_banner_unit_id, 
                :admob_native_unit_id, 
                :admob_interstitial_unit_id, 
                :admob_rewarded_unit_id, 
                :admob_app_open_unit_id, 

                :unity_game_id, 
                :unity_banner_unit_id, 
                :unity_interstitial_unit_id, 
                :unity_rewarded_unit_id,

                :interstitial_ad_interval,
                :scrolling_ad_interval,

                now()) ";
            $stmt = $pdo->prepare($sql);
            $status = $ad_enabled_status == "on" ? 1 : 0;
            $stmt->bindValue(':ad_enabled_status', $status, PDO::PARAM_INT);
            $stmt->bindValue(':ad_network', $ad_network, PDO::PARAM_STR);
            $stmt->bindValue(':admob_banner_unit_id', $admob_banner_unit_id, PDO::PARAM_STR);
            $stmt->bindValue(':admob_native_unit_id', $admob_native_unit_id, PDO::PARAM_STR);
            $stmt->bindValue(':admob_interstitial_unit_id', $admob_interstitial_unit_id, PDO::PARAM_STR);
            $stmt->bindValue(':admob_rewarded_unit_id', $admob_rewarded_unit_id, PDO::PARAM_STR);
            $stmt->bindValue(':admob_app_open_unit_id', $admob_app_open_unit_id, PDO::PARAM_STR);

            $stmt->bindValue(':unity_game_id', $unity_game_id, PDO::PARAM_STR);
            $stmt->bindValue(':unity_banner_unit_id', $unity_banner_unit_id, PDO::PARAM_STR);
            $stmt->bindValue(':unity_interstitial_unit_id', $unity_interstitial_unit_id, PDO::PARAM_STR);
            $stmt->bindValue(':unity_rewarded_unit_id', $unity_rewarded_unit_id, PDO::PARAM_STR);

            $stmt->bindValue(':interstitial_ad_interval', $interstitial_ad_interval, PDO::PARAM_INT);
            $stmt->bindValue(':scrolling_ad_interval', $scrolling_ad_interval, PDO::PARAM_INT);
            

            $updateSet = $stmt->execute() ? true : false;
            $msg = MESSAGES['UPDATE_MONETIZATION_SUCCESS'];
        }
        $isAdmin = true;
    } else {
        $isAdmin = false;
        $updateSet = false;
        $msg = MESSAGES['NO_ADMIN'];
    }
    print json_encode(array('admin' => $isAdmin, 'success' => $updateSet, 'msg' => $msg), JSON_PRETTY_PRINT);
}

?>