<?php

// Reporting E_NOTICE can be good too (to report uninitialized
// variables or catch variable name misspellings ...)
error_reporting(E_ERROR | E_WARNING | E_PARSE | E_NOTICE);

session_start();

include_once ('../config.php');
$pdo = require_once (SERVERDIR .'/database.php');
require_once (LIBSDIR .'/variables.php');
require_once (SERVERDIR .'/auth.php');

const MESSAGES = [
    'NO_ADMIN' => 'You need admin permission to access this action.',
    'SIGNUP_FAILED' => 'Registration faied.',
    'SIGNUP_SUCCESS' => 'Congurations, your account has been successfuly created.',
    'USER_EXISTS' => '$USR already exists.'
];

if(isGetRequest()) {
    echo json_encode(array('success' => false, 'msg' => 'isCurrentLogedInAsAdmin'), JSON_PRETTY_PRINT);
}

if(isPostRequest()) {
    if(isset($_REQUEST['query'])) {
        switch($_REQUEST['query']) {
            case 'createAccount':
                if(isset($_REQUEST['from'])) {
                    if($_REQUEST['from'] == 'register') {
                       $isNotFromRegister = false;
                    } elseif($_REQUEST['from'] == 'addNewUser') {
                        $isNotFromRegister = true;
                    }
    
                    if($isNotFromRegister && !isCurrentLogedInAsAdmin()) {
                        print json_encode(array('success' => false, 'msg' => MESSAGES['NO_ADMIN']), JSON_PRETTY_PRINT);
                        return;
                    } 
                    if(isset($_POST['username'], $_POST['password']) &&
                        !empty($_POST['username']) && !empty($_POST['password'])) {
                            //$level = escape('level') != '' ? (escape('level') == 'admin' ? 1 : 0): 0;
                            $level = empty($_POST['level']) ? 0 : (escape('level') == 'admin' ? 1 : 0);
                            //$fullname = escape('full_name') != '' ? escape('full_name') : '';
                            $fullname = empty($_POST['full_name']) ? 'Unknown' : escape('full_name');
                            $gender = empty($_POST['gender']) ? 'Unknown' : escape('gender');
                            $country = empty($_POST['country']) ? 'Unknown' : escape('country');
                            $username = escape('username');                 
                            $email = escape('email') != '' ? escape('email') : $username.'@boumbastudios.com';                  
                            $password = escape('password');
                        
                            $options = array("cost"=>4);
                            $hashPassword = password_hash($password, PASSWORD_BCRYPT, $options);

                            //$url = "http://ip-api.com/json/?callback=?";

                            createNewUserAccount();
                    } else {
                        print json_encode(array('success' => false, 'msg' => "All fields required"), JSON_PRETTY_PRINT);
                    }
                    
                }
            break;
        }
    }
}

function checkUserAccountNotExists(): bool {
    global $pdo, $username, $email;
    $sql = 'SELECT * FROM `tb_users` WHERE (username = :username OR email = :email)'; 
    $stmt = $pdo->prepare($sql);
    $stmt->bindValue(':username', $username, PDO::PARAM_STR); 
    $stmt->bindValue(':email', $email, PDO::PARAM_STR);
    $stmt->execute();
    $numRows = $stmt->fetchColumn();
    $stmt->closeCursor();
    return $numRows > 0 ? false : true;
}

function createNewUserAccount() {
    global $pdo, 
    $level, 
    $isNotFromRegister, 
    $fullname, 
    $username, 
    $email, 
    $hashPassword, 
    $gender,
    $country, 
    $signUpSuccess, 
    $signUpStateMsg;

    if($isNotFromRegister && !isCurrentLogedInAsAdmin()) {
        print json_encode(array("success" => false, "msg" => MESSAGES['NO_ADMIN']), JSON_PRETTY_PRINT);
        return;
    } 
    if(checkUserAccountNotExists()) {
        $sql = 'INSERT INTO `tb_users` (name, username, email, password, 
        identifier, gender, picture, country, level, created_at)
        VALUES(:name,:username,:email,:pass,:uniqueid,:gender,:pic,:country,:role,:date)';
        $stmt = $pdo->prepare($sql);
        $stmt->bindValue(':name', $fullname, PDO::PARAM_STR);
        $stmt->bindValue(':username', strtolower($username), PDO::PARAM_STR);
        $stmt->bindValue(':email', $email, PDO::PARAM_STR);
        $stmt->bindValue(':pass', $hashPassword, PDO::PARAM_STR);
        $stmt->bindValue(':uniqueid', genRandomNumber(9, false), PDO::PARAM_INT);
        $stmt->bindValue(':gender', $gender, PDO::PARAM_STR);
        $stmt->bindValue(':pic', 'profile.png', PDO::PARAM_STR);
        $stmt->bindValue(':country', $country, PDO::PARAM_STR);
        $stmt->bindValue(':role', $level, PDO::PARAM_INT);
        $stmt->bindValue(':date', date("Y-m-d H:i:s"));
        $resultSet = $stmt->execute();
        if($resultSet) {
            $signUpSuccess = true;
            $signUpStateMsg = MESSAGES['SIGNUP_SUCCESS'];
        } else {
            $signUpStateMsg = MESSAGES['SIGNUP_FAILED'];
            $signUpSuccess = false;
        }
    } else {
        $signUpStateMsg = str_replace('$USR', "The User", MESSAGES['USER_EXISTS']);
        $signUpSuccess = false;
    }
    print json_encode(array('success' => $signUpSuccess, 'msg' => $signUpStateMsg), JSON_PRETTY_PRINT);
}

?>