<?php
session_start();
require_once ('../config.php');
$pdo = require_once (SERVERDIR .'/database.php');
require_once (SERVERDIR .'/auth.php');
require_once (LIBSDIR .'/variables.php');

const MESSAGES = [
    'NO_ADMIN' => 'You need admin permission to access this action.',
    'GENRATE_TOKEN_SUCCESS' => 'Has been new token generated successfully',
    'GENRATE_TOKEN_FAILED' => 'Generate token faied.',
    'GENRATE_TOKEN_EXISTS' => 'Access token exists.',
    'UPDATE_TOKEN_SUCCESS' => 'Update token successfully.',
    'UPDATE_TOKEN_FAILED' => 'Update token faied.',
    'DELETE_TOKEN_SUCCESS' => 'Delete token successfully.',
    'DELETE_TOKEN_FAILED' => 'Delete faied. Access token is not exists.'
];

if(isPostRequest() && isUserLogedIn()) {
    if(isset($_REQUEST['query'])) {
        switch($_REQUEST['query']) {
            case 'fetchToken':
                parseTokenToJson();
                //print json_encode(array('array' => "List Items"));
                break;
            case 'generateToken':
                if(!isCurrentLogedInAsAdmin()) {
                    print json_encode(array("success" => false, "msg" => MESSAGES['NO_ADMIN']), JSON_PRETTY_PRINT);
                    return;
                } 
                generateNewToken();
                break;
            case 'deleteToken':
                if(!isCurrentLogedInAsAdmin()) {
                    print json_encode(array("success" => false, "msg" => MESSAGES['NO_ADMIN']), JSON_PRETTY_PRINT);
                    return;
                } 
                if(isset($_REQUEST['token']) && !empty($_REQUEST['token'])) {
                    $validator = string_strip(['request' => 'token']);
                    deleteToken();
                }
                break;
        }
    }
}

function getTokenValidator() {
    return getTokens() ? getTokens()['hashed_validator'] : 'No token found';
}

function getTokens() {
    global $pdo;
    $sql = "SELECT * FROM `tb_tokens`"; 
    $stmt = $pdo->prepare($sql);
    $stmt->execute();
    $row = $stmt->fetch(PDO::FETCH_ASSOC);
    $stmt->closeCursor();
    return $row;
}

function parseTokenToJson() {
    print json_encode(array('success' => getTokens() ? true : false, 'selector' => getTokens()['selector'], 'token' => getTokens()['hashed_validator']), JSON_PRETTY_PRINT);
}

function generateNewToken() {
    global $pdo, $isAdmin, $msg;
   

    if(isCurrentLogedInAsAdmin()) {
        if(getTokens() > 0) {
            $updateSet = true;
            $msg = MESSAGES['GENRATE_TOKEN_EXISTS'];
        } else {
            $selector = bin2hex(random_bytes(16));
            $validator = bin2hex(random_bytes(32));
            $futureDate = mktime(0, 0, 0, date("m")+60, date("d"), date("Y"));
            $creation_date = date("Y-m-d H:i:s", $futureDate);
            
            $sql = "INSERT INTO `tb_tokens` (selector, hashed_validator, expiry) VALUES (:selector, :validator, :date) ";
            $stmt = $pdo->prepare($sql);
            $stmt->bindValue(':selector', $selector, PDO::PARAM_STR);
            $stmt->bindValue(':validator', $validator, PDO::PARAM_STR);
            $stmt->bindValue(':date', $creation_date, PDO::PARAM_STR);
            $updateSet = $stmt->execute() ? true : false;
            $msg = MESSAGES['GENRATE_TOKEN_SUCCESS'];
        }
        $isAdmin = true;
    } else {
        $isAdmin = false;
        $updateSet = false;
        $msg = MESSAGES['NO_ADMIN'];
    }

    print json_encode(array('admin' => $creation_date, 'success' => $updateSet, 'token' => getTokenValidator(), 'msg' => $msg), JSON_PRETTY_PRINT);
}

// function generate_tokens() {
//     //$hashedValidator = $selector . ':' . $validator;
//     //print json_encode(array('admin' => true, 'success' => true, 'token' => $validator, 'msg' => "has been new token generated successfully"), JSON_PRETTY_PRINT);
//     updateTokens();
//     //return [$selector, $validator, $selector . ':' . $validator];
// }

function parse_token(string $token): ?array {
    $parts = explode(':', $token);

    if ($parts && count($parts) == 2) {
        return [$parts[0], $parts[1]];
    }
    return null;
}

function checkTokenExists(): bool {
    global $pdo, $validator;
    $sql = 'SELECT * FROM `tb_tokens` WHERE hashed_validator = :validator'; 
    $stmt = $pdo->prepare($sql);
    $stmt->bindValue(':validator', $validator, PDO::PARAM_STR); 
    $stmt->execute();
    $numRow = $stmt->fetchColumn();
    return $numRow ? true : false;
}

function deleteToken() {
    global $pdo, $isAdmin, $validator, $msg;

    if(isCurrentLogedInAsAdmin()) {
        if(checkTokenExists()) {
            $sql = 'DELETE FROM `tb_tokens` WHERE hashed_validator = :validator';
            $stmt = $pdo->prepare($sql);
            $stmt->bindValue(':validator', $validator, PDO::PARAM_STR);
            $deleteSet = $stmt->execute() ? true : false;
            $msg = MESSAGES['DELETE_TOKEN_SUCCESS'];
        } else {
            $deleteSet = false;
            $msg = MESSAGES['DELETE_TOKEN_FAILED'];
        }
        $isAdmin = true;
    } else {
        $isAdmin = false;
        $deleteSet = false;
        $msg = MESSAGES['NO_ADMIN'];
    }
    print json_encode(array('admin' => $isAdmin, 'success' => $deleteSet, 'msg' => $msg), JSON_PRETTY_PRINT);
}

?>