<?php
session_start();
include_once('../config.php');
$pdo = require_once  SERVERDIR .'/database.php';
require_once LIBSDIR .'/variables.php';
require_once SERVERDIR .'/auth.php';

const MESSAGES = [
    'NO_ADMIN' => 'You need admin permission to access this action.',
    'ADD_SUCCESS' => '$WALL has been successfuly added.',
    'ADD_FAILED' => '$WALL add faied.',
    'DELETE_SUCCESS' => '$WALL deleted successfully.',
    'DELETE_FAILED' => '$WALL not exists.',
    'UPDATE_SUCCESS' => 'Updated successfully',
    'UPDATE_FAILED' => 'Update fail.',
    'FIELDS_EMPTY' => 'All fields required.',
    'NO_RESULT' => 'No result.',
    'URL_EMPTY' => 'URL Image field is empty.',
    'URL_INVALID' => 'URL Image invalid.',
    'URL_SERVER_ERROR' => 'URL Image server invalid.'
];

if(isPostRequest() && isUserLogedIn()) {
    if(isset($_REQUEST['query'])) {
        switch($_REQUEST['query']) {
            case 'fetchAllWallpapers':
                if(isset($_REQUEST['page'], $_REQUEST['perpage'])) {
                    getWallpapers(string_strip(['request' => 'page']), string_strip(['request' => 'perpage']));
                } else {
                    print unknownError();
                }
                break;
            case 'fetchWallpaperById':
                if(isset($_REQUEST['identifier'])) {
                    if(!isCurrentLogedInAsAdmin()) {
                        return;
                    } 
                    $identifier = string_strip(['request' => 'identifier']);
                    print json_encode(getWallpaperById(), JSON_PRETTY_PRINT);
                } else {
                    print unknownError();
                }
                break;    
            case 'addwallpaper':
                if(!isCurrentLogedInAsAdmin()) {
                    print json_encode(array("success" => false, "msg" => MESSAGES['NO_ADMIN']), JSON_PRETTY_PRINT);
                    return;
                } 
                if(isset($_REQUEST['publisher_id'], $_REQUEST['wallpaper_name'], $_REQUEST['images_links']) &&
                        !empty($_REQUEST['publisher_id']) && !empty($_REQUEST['wallpaper_name']) && !empty($_REQUEST['images_links'])) {

                            $publisherid = string_strip(['request' => 'publisher_id']);
                            $wallpapername = string_strip(['request' => 'wallpaper_name']);
                            $links = string_strip(['request' => 'images_links']);

                            addNewWallpaper();
                } else {
                    print json_encode(array("success" => false, "msg" => MESSAGES['FIELDS_EMPTY']), JSON_PRETTY_PRINT);
                }
                break; 
            case 'updateWallpaperById':
                if(isset($_REQUEST['identifier'], $_REQUEST['wallpaper_name'], $_REQUEST['wallpaper_url'])) {
                    
                    $identifier = string_strip(['request' => 'identifier']);
                    $wallpaperName = string_strip(['request' => 'wallpaper_name']);
                    $wallpaperUrl = string_strip(['request' => 'wallpaper_url']);
                    if(!isCurrentLogedInAsAdmin()) {
                        print json_encode(array("success" => false, "msg" => MESSAGES['NO_ADMIN']), JSON_PRETTY_PRINT);
                        return;
                    } 
                    updateWallpaperById();
                } else {
                    print unknownError();
                }
                break;
            case 'deleteWallpaperById':
                if(isset($_REQUEST['identifier'])){
                    $identifier = string_strip(['request' => 'identifier']);
                    if(!isCurrentLogedInAsAdmin()) {
                        print json_encode(array("success" => false, "msg" => MESSAGES['NO_ADMIN']), JSON_PRETTY_PRINT);
                        return;
                    } 
                    deleteWallpaperById();
                } else {
                    print unknownError();
                }
                break;
            case 'fetchUsers':
                 getAllUsers();
                break;
            case 'searchById':
                if(!isCurrentLogedInAsAdmin()) {
                    //print json_encode(array("success" => false, "msg" => MESSAGES['NO_ADMIN']), JSON_PRETTY_PRINT);
                    return;
                } 
                if(isset($_REQUEST['keyword']) && !empty($_REQUEST['keyword'])) {
                    $keyword = string_strip(['request' => 'keyword']);
                    print searchWallpaperById();
                } else {
                    //print json_encode(array("success" => false, "msg" => MESSAGES['NO_RESULT']), JSON_PRETTY_PRINT);
                    //print noWallpapers();
                    //print string_strip(['request' => 'page']);
                    getWallpapers(string_strip(['request' => 'page']), string_strip(['request' => 'perpage']));
                }
                break;
        }
    }
}

function addNewWallpaper() {
    global $pdo, $publishername, $publisherid, $wallpapername, $links,
    $isAdmin, $msg, $resultSet;

    if(isCurrentLogedInAsAdmin()) {
        $linkLines = explode("\r\n", $links);
        foreach($linkLines as $link) {
            $newlink = preg_replace('/\s+/', '', $link);        
            $sql = 'INSERT INTO `tb_images` (name, url, identifier, views, downloads, publisher_id, publisher_name, created_at)
                    VALUES(:catname,:link,:uniqueid,0,0,:publisherid,:publishername,now())';
            $statment = $pdo->prepare($sql);
            $statment->bindValue(':catname', $wallpapername, PDO::PARAM_STR);
            $statment->bindValue(':link', $newlink, PDO::PARAM_STR);
            $statment->bindValue(':uniqueid', genRandomNumber(9, false), PDO::PARAM_STR);
            $statment->bindValue(':publisherid', $publisherid, PDO::PARAM_INT);
            $statment->bindValue(':publishername', '', PDO::PARAM_STR);
            $resultSet = $statment->execute();
        }
        $isAdmin = true;
        $resultSet ? $msg = str_replace('$WALL', 'Wallpaper', MESSAGES['ADD_SUCCESS']) : $msg = str_replace('$WALL', 'Wallpaper', MESSAGES['ADD_FAILED']);   
    } else {
        $isAdmin = false;
        $resultSet = false;
        $msg = MESSAGES['NO_ADMIN'];
    }    
    echo json_encode(array('admin' => $isAdmin, 'success' => $resultSet ? true : false, 'msg' => $msg), JSON_PRETTY_PRINT);
}

function getWallpapers($page, $perpage) {
    global $pdo;

    $html = '';  
    $start = ($page -1) * $perpage;
    $rowCount = numOfRows();

    $query = "SELECT * FROM `tb_images` ORDER BY `id` DESC LIMIT " .$start. "," . $perpage ;
    
    $stmt = $pdo->prepare($query);
    $stmt->execute();
    $rows = $stmt->fetchAll(PDO::FETCH_ASSOC);
    $stmt->closeCursor();
    
    // Records
    $html .= '<div class="row" id="wallpapers-list">';

    if($rowCount) {
        // Content
        foreach($rows as $wallpaper) {
             $html .= content($wallpaper);
        }
        // Pagination
        $html .= pagination($rowCount, $page, $perpage);
    } else {
        $html .= noWallpapers();
    }

    $html .= '</div>';

    print $html;
}

function content($wallpaper) {
    $html = '';
    $url = "" .htmlentities($wallpaper['url'], ENT_QUOTES, 'UTF-8'). "";

            
    $editIfUserAsAdmin = isCurrentLogedInAsAdmin() ? 'data-id="' . $wallpaper['identifier'] . '" data-toggle="modal" data-target="#edit-wallpaper-modal" id="edit-wallpaper-modal"' : 'class="d-inline-block" tabindex="0" data-toggle="tooltip" title="You need admin permission to access this action"';
    $deleteIfUserAsAdmin = isCurrentLogedInAsAdmin() ? 'data-id="' . $wallpaper['identifier'] . '" data-toggle="modal" data-target="#delete-wallpaper-modal" id="delete-wallpaper-modal"' : 'class="d-inline-block" tabindex="0" data-toggle="tooltip" title="You need admin permission to access this action"';
    $disable = isCurrentLogedInAsAdmin() ? '' : 'disabled';
    $disablePointer = isCurrentLogedInAsAdmin() ? '' : 'pointer-events: none;';

    //$imageURL = getHttpResponseCode($url) == 200 ? $url : 'assets/img/loading-hourglass.svg';

    $html .= '<div class="col-lg-2 col-md-3 col-sm-6 col-xs-3" id="row_'.$wallpaper['identifier'].'">';
    $html .= '<div class="card profile-card-1">';
    //$html .= '<img src="' .$imageURL. '" style="height: 100%;">';
    $html .= '<img src="assets/img/loading-hourglass.svg" onload=onLoadImage(this,"'.$url.'"); onerror="onErrorImage(this);" style="height: 100%;">';
    
    $html .= '<div class="card-img-overlay bg-overlay">';
    $html .= '<div class="card-content">';
    $html .= '<div class="icon-block">';
    $html .= '<a href="javascript:void(0)" class=" bs-tooltip" data-toggle="tooltip" title="'.thousandsCurrencyFormat($wallpaper['views']).' Views"><i class="fa fa-eye"></i></a>';
    $html .= '<a href="javascript:void(0)" class=" bs-tooltip" data-toggle="tooltip" title="'.thousandsCurrencyFormat($wallpaper['downloads']).' Downloads"><i class="fa fa-download"></i></a>';

    $html .= '<span '.$editIfUserAsAdmin.'>';
    $html .= '<a href="javascript:void(0)" class=" bs-tooltip '.$disable.'" data-toggle="tooltip" title="Edit" data-toggle="modal" data-target="#exampleModalCenter" style="'.$disablePointer.'"><i class="fa fa-edit"></i></a>';
    $html .= '</span>';

    $html .= '<span '.$deleteIfUserAsAdmin.'>';
    $html .= '<a href="javascript:void(0)" class=" bs-tooltip '.$disable.'" data-toggle="tooltip" title="Delete" data-toggle="modal" data-target="#exampleModalCenter" style="'.$disablePointer.'"><i class="fa fa-trash"></i></a>';
    $html .= '</span>';

    $html .= '</div>';
    $html .= '</div>';
    $html .= '</div>';
    $html .= '</div>';
    $html .= '</div>'; 
    
    return $html;
}

function pagination($count, $page, $perpage) {
    $html = '';
    $pages = ceil($count / $perpage);
   
    $next = $page;

    $html .= '<div class="col-md-12 col-xs-12">';
    $html .= '<div class="paginating-container pagination-default">';
    $html .= '<ul class="pagination">';

    $previous = $page - 1;

    //$html .= '<script>console.log("Pages: ' .$pages. ' ")</script>';
    //$html .+ '****************************************************';
    //$html .= '<script>console.log("Current Page: ' .$page. ' ")</script>';

    //$html .= '<script>console.log("Previous Page: ' .$previous. ' ")</script>';

    if($previous !== 0) {
        $html .= '<li class="pag-link first" id="1"><a>First</a></li>';
        $html .= '<li class="pag-link prev" id='.$previous.'><a>Prev</a></li>';
    } else {
        $html .= '<li class="first" aria-disabled="true"><a>First</a></li>';
        $html .= '<li class="prev"><a aria-disabled="true">Prev</a></li>';
    } 
    
    for($i = 1; $i <= $pages; $i++) {
        if($i == $page) {
            $html .= '<li class="pag-link active" id='.$i.'><a>'.$i.'</a></li>';
        } else {
            $html .= '<li class="pag-link" id='.$i.'><a>'.$i.'</a></li>';
        }
    }
    if($page < $pages) {
        $html .= '<li class="pag-link next" id='.($next += 1).'><a>Next</a></li>';
        $html .= '<li class="pag-link last" id='.$pages.'><a>Last</a></li>';
    } else {
        $html .= '<li class="next" aria-disabled="true"><a>Next</a></li>';
        $html .= '<li class="last"><a aria-disabled="true">Last</a></li>';
    }
    $html .= '</ul>';
    $html .= '</div>';
    $html .= '</div>';
    return $html;
}

function noWallpapers() {
    $html = '';
    $html .= '<div class="container">';
    $html .= '<div class="text-center">';
    $html .= '<img src="assets/img/no_photo.svg" at="..." style="width: 100px;height:100px;"></img>';
    //$html .= '<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-frown">';
    //$html .= '<circle cx="12" cy="12" r="10"></circle><path d="M16 16s-1.5-2-4-2-4 2-4 2"></path><line x1="9" y1="9" x2="9.01" y2="9"></line><line x1="15" y1="9" x2="15.01" y2="9"></line>';
    //$html .= '</svg>';
    $html .= '<h4>No wallpapers found!</h4>';
    $html .= '</div>';
    $html .= '</div>';
    return $html;
}

function unknownError() {
    $html = '';
    $html .= '<div class="container">';
    $html .= '<div class="text-center">';
    $html .= '<img src="assets/img/noun-emotion.svg" at="..." style="width: 100px;height:100px;"></img>';
    $html .= '<h4>Unknown error</h4>';
    $html .= '</div>';
    $html .= '</div>';
    return $html;
}

function getWallpaperById() {
    global $pdo, $identifier;
    $sql = "SELECT * FROM `tb_images` WHERE identifier =  $identifier "; 
    $stmt = $pdo->prepare($sql);
    $stmt->execute();
    $row = $stmt->fetch(PDO::FETCH_ASSOC);
    $stmt->closeCursor();
    return $row;
}

function searchWallpaperById() {
    global $pdo, $keyword, $html;
    $sql = "SELECT * FROM `tb_images` WHERE identifier = :ID "; 
    $stmt = $pdo->prepare($sql);
    $stmt->bindValue(':ID', $keyword, PDO::PARAM_STR);
    $stmt->execute();
    $row = $stmt->fetch(PDO::FETCH_ASSOC);
    $stmt->closeCursor();

    // Records
    $html .= '<div class="row" id="wallpapers-list">';

    if($row) {
        $html .= content($row);
    } else {
        $html .= noWallpapers();
    }

    $html .= '</div>';

    return $html;
}

function numOfRows() {
    global $pdo;
    $sql = 'SELECT COUNT(*) FROM `tb_images`'; 
    $stmt = $pdo->prepare($sql);
    $stmt->execute();
    $numRow = $stmt->fetchColumn();
    $stmt->closeCursor();
    return $numRow;
}

function checkWallpaperExists(): bool {
    global $pdo, $identifier;

    $sql = 'SELECT identifier FROM `tb_images` WHERE (identifier = :uniqueId)'; 
    $stmt = $pdo->prepare($sql);
    $stmt->bindValue(':uniqueId', $identifier, PDO::PARAM_INT); 
    $stmt->execute();
    $numRow = $stmt->fetchColumn();
    return $numRow > 1 ? true : false;
}

function updateWallpaperById() {
    global $pdo, $identifier, $wallpaperName, $wallpaperUrl;
    
    $isAdmin = '';
    $msg = '';

    if(isCurrentLogedInAsAdmin()) {
        if(checkWallpaperExists()) {
            if(!empty($wallpaperUrl)) {
                if(filter_var($wallpaperUrl, FILTER_VALIDATE_URL) && getHttpResponseCode($wallpaperUrl) == 200) {
                    $sql = "UPDATE `tb_images` SET name = :name, url = :url, created_at = :date WHERE identifier = " . $identifier . "";
                    $stmt = $pdo->prepare($sql);
                    $stmt->bindValue(':name', $wallpaperName, PDO::PARAM_STR);
                    $stmt->bindValue(':url', $wallpaperUrl, PDO::PARAM_STR);
                    $stmt->bindValue(':date', date("Y-m-d H:i:s"));
                    $updateSet = $stmt->execute() ? true : false;
                    $msg = str_replace('$WALL', 'Wallpaper', MESSAGES['UPDATE_SUCCESS']);
                } else {
                    $updateSet = false;
                    $msg = str_replace('$WALL', 'Wallpaper', MESSAGES['URL_INVALID']);
                }
            } else {
                $updateSet = false;
                $msg = str_replace('$WALL', 'Wallpaper', MESSAGES['URL_EMPTY']);
            }
        } else {
            $updateSet = false;
            $msg = str_replace('$WALL', 'Wallpaper', MESSAGES['UPDATE_FAILED']);
        }
        $isAdmin = true;
    } else {
        $isAdmin = false;
        $updateSet = false;
        $msg = MESSAGES['NO_ADMIN'];
    }
    print json_encode(array('admin' => $isAdmin, 'success' => $updateSet, 'msg' => $msg), JSON_PRETTY_PRINT);
}

function deleteWallpaperById() {
    global $pdo, $identifier, $isAdmin, $msg;

    if(isCurrentLogedInAsAdmin()) {
        if(checkWallpaperExists()) {
            $sql = "DELETE FROM `tb_images` WHERE identifier = " . $identifier . "";
            $stmt = $pdo->prepare($sql);
            $deleteSet = $stmt->execute() ? true : false;
            $msg = str_replace('$WALL', 'Wallpaper', MESSAGES['DELETE_SUCCESS']);
        } else {
            $deleteSet = false;
            $msg = str_replace('$WALL', 'Wallpaper', MESSAGES['DELETE_FAILED']);
        }
        $isAdmin = true;
    } else {
        $isAdmin = false;
        $deleteSet = false;
        $msg = MESSAGES['NO_ADMIN'];
    }
    print json_encode(array('admin' => $isAdmin, 'success' => $deleteSet, 'msg' => $msg), JSON_PRETTY_PRINT);
}

function getAllUsers() {
    global $pdo;
    $sql = 'SELECT name, username, identifier FROM `tb_users`'; 
    $stmt = $pdo->prepare($sql);
    $stmt->execute();
    $rows = $stmt->fetchAll(PDO::FETCH_ASSOC);
    $stmt->closeCursor();
    $usersArray = array();
    if($rows > 0) {
        $resultSet = true;
        foreach($rows as $row) {
            array_push($usersArray, $row);
        }
    } else {
        $resultSet = false;
    }
    echo json_encode($usersArray, JSON_PRETTY_PRINT);
}

?>